import { JSONObject } from "types-json";
import { ESLintConfig } from "types-eslintrc";
export { JSONObject };
export declare type Primitive = null | undefined | string | number | boolean | symbol | bigint;
export declare type LiteralUnion<LiteralType extends BaseType, BaseType extends Primitive> = LiteralType | (BaseType & {
    _?: never;
});
export declare type Person = string | {
    name: string;
    url?: string;
    email?: string;
};
export declare type BugsLocation = string | {
    url?: string;
    email?: string;
};
export declare type DirectoryLocations = {
    bin?: string;
    doc?: string;
    example?: string;
    lib?: string;
    man?: string;
    test?: string;
};
export declare type Scripts = {
    prepublish?: string;
    prepare?: string;
    prepublishOnly?: string;
    prepack?: string;
    postpack?: string;
    publish?: string;
    postpublish?: string;
    preinstall?: string;
    install?: string;
    postinstall?: string;
    preuninstall?: string;
    uninstall?: string;
    postuninstall?: string;
    preversion?: string;
    version?: string;
    postversion?: string;
    pretest?: string;
    test?: string;
    posttest?: string;
    prestop?: string;
    stop?: string;
    poststop?: string;
    prestart?: string;
    start?: string;
    poststart?: string;
    prerestart?: string;
    restart?: string;
    postrestart?: string;
} & {
    [scriptName in string]?: string;
};
export declare type Dependencies = {
    [packageName: string]: string;
};
export declare type Repository = string | {
    type: LiteralUnion<"git" | "svn", string>;
    url: string;
    directory?: string;
};
export declare type NonStandardEntryPoints = {
    module?: string;
    esnext?: string | {
        [moduleName: string]: string | undefined;
        main?: string;
        browser?: string;
    };
    browser?: string | {
        [moduleName: string]: string | false;
    };
    sideEffects?: boolean | string[];
};
export { ESLintConfig };
export declare type TypeScriptConfiguration = {
    types?: string;
    typings?: string;
};
export declare type WorkspaceConfig = {
    packages?: WorkspacePattern[];
    nohoist?: WorkspacePattern[];
};
export declare type WorkspacePattern = string;
export declare type YarnConfiguration = {
    workspaces?: WorkspacePattern[] | WorkspaceConfig;
    flat?: boolean;
    resolutions?: Dependencies;
};
export declare type JSPMConfiguration = {
    jspm?: PackageJSON;
};
export declare type ESLintConfiguration = {
    eslintConfig?: ESLintConfig;
};
export declare type LicenseID = LiteralUnion<"MIT" | "ISC", string>;
export declare type PackageJSON = JSONObject & {
    name?: string;
    version?: string;
    description?: string;
    keywords?: string[];
    homepage?: LiteralUnion<".", string>;
    bugs?: BugsLocation;
    license?: LicenseID;
    licenses?: Array<{
        type?: LicenseID;
        url?: string;
    }>;
    author?: Person;
    contributors?: Person[];
    maintainers?: Person[];
    files?: string[];
    main?: string;
    bin?: string | {
        [binary: string]: string;
    };
    man?: string | string[];
    directories?: DirectoryLocations;
    repository?: Repository;
    scripts?: Scripts;
    config?: JSONObject;
    dependencies?: Dependencies;
    devDependencies?: Dependencies;
    optionalDependencies?: Dependencies;
    peerDependencies?: Dependencies;
    peerDependenciesMeta?: {
        [packageName: string]: {
            optional: true;
        };
    };
    bundledDependencies?: string[];
    bundleDependencies?: string[];
    engines?: {
        [EngineName in "npm" | "node" | string]: string;
    };
    engineStrict?: boolean;
    os?: Array<LiteralUnion<"aix" | "darwin" | "freebsd" | "linux" | "openbsd" | "sunos" | "win32" | "!aix" | "!darwin" | "!freebsd" | "!linux" | "!openbsd" | "!sunos" | "!win32", string>>;
    cpu?: Array<LiteralUnion<"arm" | "arm64" | "ia32" | "mips" | "mipsel" | "ppc" | "ppc64" | "s390" | "s390x" | "x32" | "x64" | "!arm" | "!arm64" | "!ia32" | "!mips" | "!mipsel" | "!ppc" | "!ppc64" | "!s390" | "!s390x" | "!x32" | "!x64", string>>;
    preferGlobal?: boolean;
    private?: boolean;
    publishConfig?: JSONObject;
    funding?: string | {
        type?: LiteralUnion<"github" | "opencollective" | "patreon" | "individual" | "foundation" | "corporation", string>;
        url: string;
    };
} & NonStandardEntryPoints & TypeScriptConfiguration & YarnConfiguration & JSPMConfiguration & JSONObject & ESLintConfiguration;
